@@ -125,6 +125,8 @@ c          read segmented atmosphere data
       call creadAtmosD
 c          manipulate data
       call catmosCnst1
+#elif ATMOSPHERE == 3
+      call creadAtmosD  ! use NRL
 #endif
 c         init for geomag
       call crdGeomag(GeomagFile, YearOfGeomag)
