@@ -21,6 +21,8 @@ c          and corresponding init.
       do i = 1, MaxIntMdls
          ModelList(i) = ' '
          InteErg(i) = 2.d12  ! GeV 10^21 eV
+         ModelList2(i) = ' '
+         InteErg2(i) = 2.d12  ! GeV 10^21 eV
       enddo
 c             ModelList       InteErg
 c              "xxx"            100.
@@ -29,10 +31,17 @@ c
 c              "xxx"            1.d12      ====>  xxx at entier energy.
 c
       IntModel(64:64) = '/'
-
+      if( XsecModel == " ") then
+         XsecModel = IntModel
+      else
+         XsecModel(64:64) = '/'
+      endif
 
       read(IntModel, *, Err=100)
      *    (ModelList(i), InteErg(i), i=1, MaxIntMdls)
+      read(XsecModel, *, Err=100)
+     *    (ModelList2(i), InteErg2(i), i=1, MaxIntMdls)
+
       do i = 1, MaxIntMdls
          if(ModelList(i) .eq. ' ') then
             NoOfMdls = i-1
@@ -41,6 +50,15 @@ c
       enddo
       NoOfMdls = MaxIntMdls
  10   continue
+      do i = 1, MaxIntMdls
+         if(ModelList2(i) .eq. ' ') then
+            NoOfMdls2 = i-1
+            goto 20
+         endif
+      enddo
+      NoOfMdls2 = MaxIntMdls
+ 20   continue
+
       do i = 1, NoOfMdls-1
 !         if(InteErg(i) .ge. InteErg(i+1)) then
          if(InteErg(i) > InteErg(i+1)) then  ! v7.633
@@ -66,15 +84,45 @@ c                 energy region invalid
          endif
 
       enddo
+      do i = 1, NoOfMdls2-1
+         if(InteErg2(i) > InteErg2(i+1)) then  
+c                 energy region invalid
+            call cerrorMsg(
+     *           'XsecModel is invalid; energy region not ascending', 1)
+            call cerrorMsg(XsecModel, 0)
+         elseif(InteErg2(i) == InteErg2(i+1)) then
+            write(0,*) '================================='
+            write(0,*)
+     *        i,'-th and ',i+1,'-th energy in IntModle are same' 
+            write(0,*) 'The model specified is',ModelList2(i+1), '.'
+            write(0,*) 'It will not be used explicitly but might be'
+            write(0,*) 'used when some model needs help for a '
+            write(0,*) 'specific particle. dpmjet3 is a good  ' 
+            write(0,*) 'candidate of such a model'
+            write(0,*) '================================='
+         endif
+
+      enddo
+
 c         exam models
       do i = 1, NoOfMdls
          do j = 1, nmdls
-            if( ModelList(i) .eq.  RegMdls(j) ) goto 20
+            if( ModelList(i) .eq.  RegMdls(j) ) goto 25
          enddo
          call cerrorMsg( ModelList(i),  1)
          call cerrorMsg('above model is not yet registered', 0)
- 20      continue
+ 25      continue
       enddo
+c         exam models
+      do i = 1, NoOfMdls2
+         do j = 1, nmdls
+            if( ModelList2(i) .eq.  RegMdls(j) ) goto 28
+         enddo
+         call cerrorMsg( ModelList2(i),  1)
+         call cerrorMsg('above model is not yet registered', 0)
+ 28      continue
+      enddo
+
 c
       if( index(IntModel, 'fritiof1.6') .gt. 0 .or.
      *    index(IntModel, 'nucrin') .gt. 0  .or.
@@ -87,16 +135,22 @@ c                                    for some particles
          call haddenC
          call chanwnC
       endif
-      if( index(IntModel, 'phits') .gt. 0  ) then
+      if( index(IntModel, 'phits') .gt. 0  .or.
+     *    index(XsecModel, 'phits') .gt. 0 ) then
          call cprePhits
       endif
-      if( index(IntModel, 'qgsjet2') .gt. 0 ) then
+      if( index(IntModel, 'qgsjet2') .gt. 0 .or.
+     *    index(XsecModel, 'qgsjet2') .gt. 0 ) then
          call ciniQGS
       endif
-      if( index(IntModel, 'epos') .gt. 0 ) then
+      if( index(IntModel, 'epos') .gt. 0 .or.
+     *    index(XsecModel, 'epos') .gt. 0 ) then
          call ceposIniAll
       endif
-
+      if( index(IntModel, 'sibyll') > 0 .or.
+     *    index(XsecModel, 'sibyll') > 0 ) then
+         call csibyllinit
+      endif
       if( index(IntModel, 'incdpm3') .gt. 0 ) then
          call ciniincdpm3
       endif
@@ -110,6 +164,7 @@ c         Gheisha; init. Gheisha cannot use hadrin/nucrin in Cosmos
          ! nothing to do ?
       endif
       if( index(IntModel, 'dpmjet3') .gt. 0 .or.
+     *    index(XsecModel, 'dpmjet3') .gt. 0  .or.
      *    index(IntModel, 'incdpm3') .gt. 0  ) then
          if(from .eq. 'cosmos') then
             ! init for dpmjet.  for Cosmos
@@ -125,7 +180,7 @@ c         Gheisha; init. Gheisha cannot use hadrin/nucrin in Cosmos
 c           it is assumed that the Glauber file is
 c           specified by prefix/...GLB
 
-         elseif(from .eq. 'epics') then
+         elseif(from == 'epics' .or. from == 'gencol') then
 c              dpmjet.inp is assumed in the same directory
 c              as config file.
             call cformFullPath('dpmjet.inp', path)
@@ -211,7 +266,8 @@ c             and set it in TopDir in Zmanager.h
       if(CosOrEpi .eq. 'cosmos') then
          path = TopDir(1:TopDirLeng)//'/Data/DPM/'
      *     //file(1:klena(file))
-      elseif(CosOrEpi .eq. 'epics' .or. CosOrEpi .eq. 'check') then
+      elseif(CosOrEpi == 'epics' .or. CosOrEpi == 'check'
+     * .or. CosOrEpi == 'gencol') then
          path = PrefixConf(1:PrefixLeng)//file(1:klena(file))
       else
          call cerrorMsg(
@@ -220,3 +276,29 @@ c             and set it in TopDir in Zmanager.h
       endif
 
       end
+      subroutine cputGencolCMS(cms)
+c           this is introduced for EPOS
+c     to save the single precision boost in EPOS
+c     call afinal is avoided to convert cms to lab
+c     conversion of which result becomes not accurate 
+c     if we convet it to cms again. (Gencol needs to do so)
+c
+      implicit none
+#include "Zptcl.h"
+      record /ptcl/ cms ! input. Gencol must
+                      ! inform the cms (/n)
+
+      common /forGencol/ cmsSave
+      record /ptcl/ cmsSave
+      cmsSave = cms
+      end
+      subroutine cqGencolCMS(cms)
+c      ask gencol cms
+c
+      implicit none
+#include "Zptcl.h"
+      record /ptcl/ cms  ! outut. 
+      common /forGencol/ cmssave
+      record /ptcl/ cmsSave
+      cms = cmsSave 
+      end
