@@ -4,14 +4,14 @@ c        nbarp total xsection, nbarp ela
       real*8 p  ! input.  momentum of nbar. in GeV
       real*8 xs     ! output. total nbarp cross section in mb
       call cpbarpTotXs(p, xs)
-      end
+      end      subroutine cnbarpTotXs
       subroutine cnbarpElaXs(p, xs)
 c           pbarp elastic cross section in mb
       implicit none
       real*8 p ! input.  momentum of pbar in GeV
       real*8  xs   ! output pbarp elastic xs. mb.
       call cpbarpElaXs(p, xs)
-      end
+      end      subroutine cnbarpElaXs
       subroutine cnbarpInelaXs(p, xs)
       implicit none
       real(8),intent(in)::p
@@ -21,4 +21,5 @@ c           pbarp elastic cross section in mb
       call cnbarpTotXs(p, txs)
       call cnbarpElaXs(p, exs)
       xs =max( txs - exs, 0.d0)
-      end
+      end      subroutine cnbarpInelaXs
+
