@@ -13,12 +13,13 @@ c
 c         get endpoint coord. assuming no scat, no mag. effect. at first
 c         MovedTrack has complete information at path end.
        MovedTrack = TrackBefMove   !   copy TrackBefMove into MovedTrack. 
-       call cmoveStreight(IntInfArray(ProcessNo).length, 
+       if(IntInfArray(ProcessNo).length .gt. 0.0 ) then
+          call cmoveStreight(IntInfArray(ProcessNo).length, 
      *             TrackBefMove.vec.w)
 c         If a chargde ptcl, compute energy loss by dE/dx  and  reset energy
 c         in MovedTrack. If it is too large, path is truncated. Also compute
 c         deflection.
-       if(IntInfArray(ProcessNo).length .gt. 0.0 ) then
+
           if(TrackBefMove.p.charge .ne. 0) then
 c            if(.not. (mod(HowGeomag, 10) .eq. 1 .and.     this existed from uv4.92 to 5.13
 c     *                Zfirst .eq. 0.)) then
@@ -195,11 +196,12 @@ c
        if(.not. nodef) then
 c
 c         compute   magnetic deflection first. independently of scattering.
-c         system is xyz
+c         system is xyz;  if Efield exists, together with it
           call cmagDef
        endif
        if(.not. nodef .and. Reverse .eq. 0) then
-          call celecDef(dispx, dispy)
+          call celecDef(dispx, dispy)  ! effect alrady put in
+                    ! MovedTrack. dispx, y are dummy
        endif
        if(.not. nodef) then
           call csetPos(MovedTrack.pos)
@@ -219,6 +221,7 @@ c                compute excess path length to be added to streight path
 c      *************************
 #include "ZsubstRec.h"
        subroutine cmagDef
+       use modEfield
        implicit none
 #include  "Zobs.h"
 #include  "Zobsp.h"
@@ -242,9 +245,25 @@ ccc    *   ,norm
        logical usemiddle, high, usecmiddle
        real*8 cheight
        data cheight/30.d3/  
+       real*8 newmom(3)
        save cheight
 
        leng = IntInfArray(ProcessNo).length
+       if( HowEfield >= 1 ) then
+          call cdefByMagAndE(TrackBefMove,  leng,  dispmr, dispmd,
+     *     newmom)
+!          note. dispmr is r(new)-r(old) vector and different
+!          from other routines below. 
+!           dispmd is new dir and set at 100
+          MovedTrack.pos.xyz.r(:) =  TrackBefMove.pos.xyz.r(:) +
+     *         dispmr.r(:) 
+          MovedTrack.p.fm.p(1:3) = newmom(:)
+           ! reset energy
+          MovedTrack.p.fm.p(4) =
+     *     sqrt( sum(  MovedTrack.p.fm.p(1:3)**2 ) + 
+     *                 MovedTrack.p.mass**2)
+          goto 100
+       endif
 c
 c            UseRungeKutta         Height       
 c                0                  any         Mag and cmagneticDef
@@ -280,7 +299,8 @@ c                8      at any height           cbDefUser ; interface is
 c                                               same as cbDefByRK
 c
        if(UseRungeKutta .eq. 8 ) then
-          call cbDefUser(TrackBefMove,  leng,  dispmr, dispmd)
+          call cbDefUser(TrackBefMove,  leng,  dispmr, dispmd,
+     *    MovedTrack.p.fm.p(1:3))
 #if defined SUBSTREC             
              MovedTrack.pos.xyz = dispmr ! this is not a dispalcement vector
 #else 
@@ -329,7 +349,8 @@ c            get curved middle point
           temp2 = Mag.x**2 + Mag.y**2 + Mag.z**2
 c           if  dB/B~ dB^2/B^2/2 > 0.4 %, use RungeKutta.
           if( abs(temp1-temp2)/temp1/2.0 .gt. 4.0d-3) then
-             call cbDefByRK2(TrackBefMove,  leng, dispmr, dispmd)
+             call cbDefByRK2(TrackBefMove,  leng, dispmr, dispmd,
+     *         MovedTrack.p.fm.p(1:3))
 #if defined SUBSTREC             
              MovedTrack.pos.xyz = dispmr ! this is not a dispalcement vector
 #else 
@@ -346,7 +367,8 @@ c           if  dB/B~ dB^2/B^2/2 > 0.45 %, use RungeKutta.
 c                  next 4.5d-3 is very sensitive to cpu time
 c                 if it was 4.0d-3, cpu time becomes twice.
           if( abs(temp1-temp2)/temp1/2.0 .gt. 4.5d-3) then
-             call cbDefByRK(TrackBefMove,  leng, dispmr, dispmd)
+             call cbDefByRK(TrackBefMove,  leng, dispmr, dispmd,
+     *         MovedTrack.p.fm.p(1:3))
 #if defined SUBSTREC             
              MovedTrack.pos.xyz = dispmr ! this is not a dispalcement vector
 #else 
@@ -361,7 +383,8 @@ c                 if it was 4.0d-3, cpu time becomes twice.
           temp2 = Mag.x**2 + Mag.y**2 + Mag.z**2
 c           if  dB/B~ dB^2/B^2/2 > 0.1 %, use RungeKutta.
           if( abs(temp1-temp2)/temp1/2.0 .gt. 4.0d-3) then
-             call cbDefByRK2(TrackBefMove,  leng, dispmr, dispmd)
+             call cbDefByRK2(TrackBefMove,  leng, dispmr, dispmd,
+     *         MovedTrack.p.fm.p(1:3))
 #if defined SUBSTREC             
              MovedTrack.pos.xyz = dispmr ! this is not a dispalcement vector
 #else 
@@ -376,7 +399,8 @@ c           if  dB/B~ dB^2/B^2/2 > 0.1 %, use RungeKutta.
           temp2 = Mag.x**2 + Mag.y**2 + Mag.z**2
 c           if  dB/B~ dB^2/B^2/2 > 0.45 %, use RungeKutta.
           if( abs(temp1-temp2)/temp1/2.0 .gt. 4.5d-3) then
-             call cbDefByRK(TrackBefMove,  leng, dispmr, dispmd)
+             call cbDefByRK(TrackBefMove,  leng, dispmr, dispmd,
+     *         MovedTrack.p.fm.p(1:3))
 #if defined SUBSTREC             
              MovedTrack.pos.xyz = dispmr ! this is not a dispalcement vector
 #else 
@@ -397,7 +421,8 @@ c           if  dB/B~ dB^2/B^2/2 > 0.45 %, use RungeKutta.
      *         dispmr.r(i)
           enddo
        elseif(UseRungeKutta .eq. 6) then
-          call cbDefByRK2(TrackBefMove,  leng, dispmr, dispmd)
+          call cbDefByRK2(TrackBefMove,  leng, dispmr, dispmd,
+     *         MovedTrack.p.fm.p(1:3))
 #if defined SUBSTREC
           MovedTrack.pos.xyz = dispmr  ! this is not a dispalcement vector
 #else 
@@ -405,7 +430,8 @@ c           if  dB/B~ dB^2/B^2/2 > 0.45 %, use RungeKutta.
 #endif
                                       !  but the vector itself.
        else
-          call cbDefByRK(TrackBefMove,  leng, dispmr, dispmd)
+          call cbDefByRK(TrackBefMove,  leng, dispmr, dispmd,
+     *         MovedTrack.p.fm.p(1:3))
 #if defined SUBSTREC
           MovedTrack.pos.xyz = dispmr  ! this is not a dispalcement vector
                                       !  but the vector itself.
