@@ -43,6 +43,27 @@ c
       stop 12345
  10   continue
 
+      do i = 1, NoOfMdls2
+         if( kepn  .lt. InteErg2(i)) then
+            ActiveMdl2 = ModelList2(i) ! used only for mfp calc
+            goto 15
+         endif
+      enddo
+
+      call cerrorMsg('XsecModel list shown below is strange', 1)
+      call cerrorMsg(XsecModel, 1)
+      call cpdpmjetinp
+      write(0,*) ' current K.E/n=',kepn,
+     *  ' code=',aPtcl.code, ' subcode=',
+     *  aPtcl.subcode, ' charge=',aPtcl.charge
+      write(0,*) '  NoOfMdls2=', NoOfMdls2
+      do i = 1,  NoOfMdls2
+         write(0,*) ' i=', i, ' InteErg2(i)=',
+     *   InteErg2(i)
+      enddo
+      stop 123456
+ 15   continue
+
       if( aPtcl.code == knuc .and.  aPtcl.subcode == antip ) then
          if(ActiveMdl == "phits" ) then
           !  ' for p-bar or n-bar, phits cannot be used'
@@ -136,3 +157,11 @@ c
       character*16 model
       model = ActiveMdl
       end
+      subroutine cqActiveMdl2(model)
+      implicit none
+#include "Zptcl.h"
+#include "Zevhnv.h"
+
+      character*16 model
+      model = ActiveMdl2
+      end
