@@ -115,7 +115,9 @@ c                  call chookEabsorbD(a, ke, 0)
      *        a.p.code .eq. kmuon) then
 c               can decay;  max energy of  last electron is Et incident
 c            allmost all decay before coming here. don't worry 
-         if(a.p.fm.p(4) .lt. KEmin) then
+c              2013/Feb.26
+c         if(a.p.fm.p(4) .lt. KEmin) then
+         if( a.p.fm.p(4) .lt. min(KEmin,KEminObs(a.p.code) )) then
 c         if(ke .lt. KEmin) then
             icon = 1
             if(a.p.fm.p(4) .lt. a.p.mass) then
