@@ -141,7 +141,10 @@ c         see if Zprimary // DetZaxis; if so reset Xprimary
          Xprimary = DetXaxis
       else
          temp =sqrt(temp)
-         Xprimary.r(:) = Xprimary.r(:)/temp         
+c                ifort v14 dies here if (:) is used  
+         Xprimary.r(1) = Xprimary.r(1)/temp         
+         Xprimary.r(2) = Xprimary.r(2)/temp         
+         Xprimary.r(3) = Xprimary.r(3)/temp         
       endif
       call cvecProd(Zprimary, Xprimary, Yprimary)
       Txyz2prim(1,:) = Xprimary.r(:)
