@@ -41,7 +41,7 @@ c         if Reverse mode = 1, use leng=rmg and thick=0
 c         if Reverse mode =other, use leng =rmg and corresponding thickness
 c
 c
-c
+      use modEfield
       implicit none
 #include  "Zcode.h"
 #include  "Ztrack.h"
@@ -52,10 +52,11 @@ c
 
       real*8 leng, thick
 c
-      real*8  ztrunc, rmg, rmgmax
+      real*8  ztrunc, rmg, rmgmax, L 
       real*8  clen2thick, erg
       integer jcut
       integer ka
+      
 
       ka =  TrackBefMove.p.code
       erg = TrackBefMove.p.fm.p(4) - TrackBefMove.p.mass 
@@ -72,6 +73,11 @@ c            magnetic deflection
 c            get max length within which B is almost const (dB< 1 %)
          call clengSmallBC(TrackBefMove, rmgmax)  
          rmg = min(rmg, rmgmax)
+!                E field effect.  Length: momentum change < 1%.
+         if( HowEfield > 0 ) then
+            call cmaxEfEffLen(TrackBefMove, L)  ! L in m
+            rmg = max(min(L, rmg), 0.1d0)
+         endif
 c            mul. scatt and lpm
          if(Reverse .eq. 0) then
 c               scattering effect; streight and scattered line must be
@@ -194,6 +200,36 @@ c                1e-3 r.l  --> 365e-3 ~  0.3 kg/m2
       endif
       kgpm2= ttrunc*X0
       end
+      subroutine cmaxEfEffLen(aTrack, L)
+!           max movable length L in m
+!          electric field exist.  length for
+!          momentum loss/gain is < 1%.
+!  dp/dt = ZeE =Z*eval*Ef  (GeV/c/s)
+!         dp = Z* eval*Ef*dt = Z*eval*Ef*dt = Z*eval*Ef*L/c (GeV/c)
+! 
+!          dp/p ~  Z*eval*Ef*L/c/p 
+!      L = dp/p /(Z*eval*Ef)*c*p
+!             if Ef=1000 V/m, p=0.1GeV/c, dp/p~0.01, Z=1
+!        L = 0.01 *3e8*0.1 /(0.3*1000) = 3e5/300 = 1000 m
+!            p=1MeV==> 10 m
+!      Ef=1.e5    50 MeV   
+!            L  = 10 m
+      use modBEfield 
+      implicit none
+#include "Ztrack.h"      
+      record /track/ aTrack  ! input current particle track
+      real(8),intent(out):: L  ! length for dp/p < 1%
+
+      real(8):: p, Ef
+      real(8),parameter:: dpbyp = 0.01d0
+      p = sqrt(dot_product(aTrack.p.fm.p(1:3),aTrack.p.fm.p(1:3)))
+
+      call cgetEfield(aTrack)  ! ans is in Efld
+
+      Ef = sqrt(dot_product( Efld(1:3), Efld(1:3))  )
+!      dpbyp =  aTrack.p.chare*eval*Ef*L/3e8/p
+      L =abs( dpbyp*p*3.0e8/(aTrack.p.charge*eval*Ef) )
+      end
 c    *************************************
       subroutine cmagDefR(aTrack, mag, r)
 c       get magnetic deflecton radius.  This is
