@@ -7,10 +7,6 @@ c            MovedTrack.p)
       implicit none
 c          special purpose routine to see the importance of
 c          energetic particles. 
-c    **** parameters are hard-wired, i.e, cannot be controled
-c         after compilation ****
-c     To chage the parameters, edit csoftenPiK.f
-c              
 c 
 #include  "Zcode.h"
 #include  "Ztrack.h"
@@ -26,12 +22,15 @@ c
       integer:: stackpos
       record /ptcl/ Tglab, Cmsp, Pjcms
       integer icon
-      
-      
+      real(8):: y, eta
+c//////////
+      record /ptcl/ temp
+c////////////////      
       
       modified = .false.
 
       if( IntInfArray(ProcessNo).process == "coll") then 
+         E0lab = proj.fm.p(4)         
          if(useXinCMS) then
 c               make proton (only for making CMS)
             call cmkptc(knuc, regptcl, 1, Tglab)
@@ -51,7 +50,7 @@ c             boost Pwork into CMS
 c                 projectile in cms
             call cbst1(2, Cmsp, proj, Pjcms)
 c                      only forward X is manipulated; fwbw is not used 
-            call csoftenFE(Pjcms,  1,  Pwork(i), Nproduced, nout)
+            call csoftenFE(Pjcms,  1,  Pwork, Nproduced, nout)  !!!!Pwork(i) bad
             Nproduced = nout
 c                 re-boost into Lab
             do i =1, Nproduced
@@ -68,37 +67,18 @@ c////////////
             Nproduced = nout
          endif
 
-c         E0 = MovedTrack.p.fm.p(4)         
-         E0 = proj.fm.p(4)         
          if(special) then
             do i = 1, Nproduced
                if( Pwork(i).code == kpion .or.
      *              Pwork(i).code == kkaon .or.
      *              Pwork(i).code == keta ) then
-                  write(*,'("xd ",2i3,  1p,g12.3)') 
-     *            Pwork(i).code, Pwork(i).charge, Pwork(i).fm.p(4)/E0
+                  call cyeta(PWork(i), y, eta)
+                  write(*,'("xd ",2i3,  1p,3g13.4)') 
+     *            Pwork(i).code, Pwork(i).charge,
+     *            Pwork(i).fm.p(4)/E0lab, y, eta
                endif
             enddo
          endif
       endif
 
-!!      if(modified) then
-!!c            since stacking has been already done, we clean
-!!c            such ptlces and  again stack 
-!!c                 get current stackpos
-!!         call cgetCurrentStackpos(stackpos)
-!!c                 adjust the pos
-!!         stackpos=stackpos-Nstacked
-!!c                 reset the stack pos. 
-!!         call cresetStackpos(stackpos)
-!!c                stack again
-!!         if(OneDim .eq. 0) then
-!!c            3 dimensional  
-!!c            stack the leading ptcl  first (to save stack area)           
-!!            call cmovePtcl3(MovedTrack, Pwork, Nproduced, Nstacked)
-!!         else
-!!            MovedTrack.vec = IncidentCopy.vec
-!!            call cmovePtcl1(MovedTrack, Pwork, Nproduced, Nstacked)
-!!         endif
-!!      endif
       end
